@@ -11,7 +11,11 @@ draw_ts_lines.ts <- function(x, theme = NULL,
 
 
 draw_ts_lines.list <- function(x, theme = NULL){
-  for (i in 1:length(x)){
+  nts <- length(x)
+  op <- rep(theme$show_points, ceiling(nts/length(theme$show_points)))
+  ops <- rep(theme$point_symbol, ceiling(nts/length(theme$point_symbol)))
+  
+  for (i in 1:nts) {
     xx <- as.numeric(time(x[[i]]))
     yy <- x[[i]]
     frq <- frequency(x[[i]])
@@ -20,14 +24,18 @@ draw_ts_lines.list <- function(x, theme = NULL){
       xx <- xx+(1/frq)/2
     }
     
+    if(theme$NA_continue_line[i]) {
+      yy_na <- is.na(yy)
+      xx <- xx[!yy_na]
+      yy <- yy[!yy_na]
+    }
+    
     lines(xx,yy,
-          col = theme$line_colors[[i]],
-          lwd = ifelse(length(theme$lwd) > 1,
-                       theme$lwd[i],
-                       theme$lwd),
-          lty = ifelse(length(theme$lty) > 1,
-                       theme$lty[i],
-                       theme$lty)
+          col = theme$line_colors[i],
+          lwd = theme$lwd[i],
+          lty = theme$lty[i],
+          type = ifelse(theme$show_points[i], "o", "l"),
+          pch = theme$point_symbol[i]
     )
   }
   
