@@ -73,7 +73,7 @@ sanitizeTsr <- function(tsr){
 
 #' @importFrom graphics abline
 addYGrids <- function(tick_positions,theme){
-  for (hl in tick_positions){
+  for (hl in tick_positions[2:length(tick_positions)]){
     abline(h = hl,
            col = theme$y_grid_color)
   } 
